@@ -94,7 +94,7 @@ TEST_CASE("ut_dssp")
 {
 	using namespace std::literals;
 
-	cif::file f(gTestDir / "1cbs.cif.gz");
+	auto f = cif::pdb::read(gTestDir / "1cbs.cif.gz");
 	REQUIRE(f.is_valid());
 
 	dssp dssp(f.front(), 1, 3, true);
@@ -110,7 +110,7 @@ TEST_CASE("ut_dssp")
 	std::string line_t, line_r;
 	CHECK((std::getline(test, line_t) and std::getline(reference, line_r)));
 
-	char kHeaderLineStart[] = "==== Secondary Structure Definition by the program DSSP, NKI version 4.4.5                         ====";
+	char kHeaderLineStart[] = "==== Secondary Structure Definition by the program DSSP, NKI version 4.5.0                         ====";
 	memcpy(kHeaderLineStart + 69, kVersionNumber, strlen(kVersionNumber));
 
 	CHECK(line_t.compare(0, std::strlen(kHeaderLineStart), kHeaderLineStart) == 0);
@@ -146,7 +146,7 @@ TEST_CASE("ut_mmcif_2")
 	using namespace std::literals;
 	using namespace cif::literals;
 
-	cif::file f(gTestDir / "1cbs.cif.gz");
+	auto f = cif::pdb::read(gTestDir / "1cbs.cif.gz");
 	REQUIRE(f.is_valid());
 
 	dssp dssp(f.front(), 1, 3, true);
@@ -178,7 +178,7 @@ TEST_CASE("ut_mmcif_2")
 
 TEST_CASE("dssp_1")
 {
-	cif::file f(gTestDir / "1cbs.cif.gz");
+	auto f = cif::pdb::read(gTestDir / "1cbs.cif.gz");
 
 	REQUIRE(f.is_valid());
 
@@ -216,7 +216,7 @@ TEST_CASE("dssp_1")
 
 TEST_CASE("dssp_2")
 {
-	cif::file f(gTestDir / "1cbs.cif.gz");
+	auto f = cif::pdb::read(gTestDir / "1cbs.cif.gz");
 
 	REQUIRE(f.is_valid());
 
@@ -253,7 +253,7 @@ TEST_CASE("dssp_2")
 
 TEST_CASE("dssp_3")
 {
-	cif::file f(gTestDir / "1cbs.cif.gz");
+	auto f = cif::pdb::read(gTestDir / "1cbs.cif.gz");
 
 	REQUIRE(f.is_valid());
 
